@@ -5,10 +5,10 @@ import argparse
 import logging
 from datetime import datetime, timedelta
 
-__version_info__ = ('0', '0', '8')
+__version_info__ = ('0', '0', '9')
 __version__ = '.'.join(__version_info__)
 
-from VideoTrackingWindow import Ui_VideoTrackingWindow
+from src.VideoTrackingWindow import Ui_VideoTrackingWindow
 from PyQt5 import QtCore, QtGui, QtWidgets, uic
 from PyQt5.QtCore import QDir, Qt, QUrl, pyqtSignal, QPoint, QRect, QObject
 from PyQt5.QtMultimedia import QMediaContent, QMediaPlayer, QVideoFrame, QAbstractVideoSurface, QAbstractVideoBuffer, QVideoSurfaceFormat, QVideoProbe
